@@ -6,6 +6,8 @@ from os import path
 
 import paddlehub as hub
 
+__EXE_SUCCESS = 0
+
 _cpu_num = os.system('cat /proc/cpuinfo | grep "processor"| wc -l')
 os.system('export CPU_NUM=%d' % (_cpu_num if _cpu_num else 2))
 
@@ -16,7 +18,8 @@ print(':: CPU_NUM: %s' % os.getenv('CPU_NUM'))
 print(':: FLAGS_eager_delete_tensor_gb: %s' % os.getenv('FLAGS_eager_delete_tensor_gb'))
 print(':: CUDA_VISIBLE_DEVICES: %s' % os.getenv('CUDA_VISIBLE_DEVICES'))
 
-_IN_AI_STUDIO = getpass.getuser() in ['aistudio', 'paddle']
+nvidia_result = os.system('lspci |grep -i nvidia')
+_IN_AI_STUDIO = getpass.getuser() in ['aistudio'] or nvidia_result == __EXE_SUCCESS
 print(':: IN_AI_STUDIO: %s' % _IN_AI_STUDIO)
 
 if _IN_AI_STUDIO:
